@@ -41,18 +41,7 @@ class PymongoDatabaseResourceFactory(object):
 class PymongoDatabaseResource(pymongo.database.Database):
     __slots__ = ()
 
-    AutoReconnect = pymongo.errors.AutoReconnect
-    CollectionInvalid = pymongo.errors.CollectionInvalid
-    ConfigurationError = pymongo.errors.ConfigurationError
-    ConnectionFailure = pymongo.errors.ConnectionFailure
-    DuplicateKeyError = pymongo.errors.DuplicateKeyError
-    InvalidName = pymongo.errors.InvalidName
-    InvalidOperation = pymongo.errors.InvalidOperation
-    InvalidURI = pymongo.errors.InvalidURI
-    OperationFailure = pymongo.errors.OperationFailure
-    PyMongoError = pymongo.errors.PyMongoError
-    TimeoutError = pymongo.errors.TimeoutError
-    UnsupportedOption = pymongo.errors.UnsupportedOption
+    pymongo = pymongo
 
     _reMongoUri = re.compile('^mongodb://((?P<userinfo>.+?)@)?(?P<hosts>.+?)(/(?P<database>.+?))(\?(?P<options>.+))?$')
     _readPreferences = {
@@ -68,7 +57,7 @@ class PymongoDatabaseResource(pymongo.database.Database):
         # Parse the mongo URI
         mMongoUri = self._reMongoUri.search(resourceString)
         if not mMongoUri:
-            raise self.InvalidURI('Invalid mongo database URI')
+            raise pymongo.errors.InvalidURI('Invalid mongo database URI')
         userinfo = mMongoUri.group('userinfo')
         hosts = mMongoUri.group('hosts')
         database = mMongoUri.group('database')
@@ -82,7 +71,7 @@ class PymongoDatabaseResource(pymongo.database.Database):
                 if option.startswith('readPreference='):
                     readPreference = self._readPreferences.get(option.split('=')[1])
                     if not readPreference:
-                        raise self.ConfigurationError('Not a valid read preference')
+                        raise pymongo.errors.ConfigurationError('Not a valid read preference')
                 else:
                     options.append(option)
 
