@@ -82,8 +82,8 @@ class PyodbcResource(object):
 
     def callproc(self, procname, *args):
         cursor = self._connection.cursor()
-        cursor.callproc(procname, *args)
-        return args, PyodbcCursorContext(cursor)
+        argsOut = cursor.callproc(procname, *args)
+        return argsOut, PyodbcCursorContext(cursor)
 
     def execute(self, query, *args):
         cursor = self._connection.cursor()
